pub enum PrepInstruction {
Show 15 variants
Polybagging,
BubbleWrapping,
Taping,
BlackShrinkWrapping,
Labeling,
HangGarment,
SetCreation,
Boxing,
RemoveFromHanger,
Debundle,
SuffocationStickering,
CapSealing,
SetStickering,
BlankStickering,
NoPrep,
}Expand description
PrepInstruction : Preparation instructions for shipping an item to Amazon’s fulfillment network. For more information about preparing items for shipment to Amazon’s fulfillment network, see the Seller Central Help for your marketplace. Preparation instructions for shipping an item to Amazon’s fulfillment network. For more information about preparing items for shipment to Amazon’s fulfillment network, see the Seller Central Help for your marketplace.
Variants
Polybagging
BubbleWrapping
Taping
BlackShrinkWrapping
Labeling
HangGarment
SetCreation
Boxing
RemoveFromHanger
Debundle
SuffocationStickering
CapSealing
SetStickering
BlankStickering
NoPrep